@@ -1046,7 +1046,10 @@ on_kerberos_inquiry (krb5_context      kerberos_context,
                      krb5_prompt       prompts[])
 {
   GoaIdentityInquiry *inquiry;
-  krb5_error_code error_code;
+  krb5_error_code error_code = 0;
+
+  if (number_of_prompts == 0)
+    goto out;
 
   inquiry = goa_kerberos_identity_inquiry_new (operation->identity,
                                                name,
@@ -1065,11 +1068,10 @@ on_kerberos_inquiry (krb5_context      kerberos_context,
 
   if (g_cancellable_is_cancelled (operation->cancellable))
     error_code = KRB5_LIBOS_PWDINTR;
-  else
-    error_code = 0;
 
   g_object_unref (inquiry);
 
+ out:
   return error_code;
 }
 
